###############################################################################################
##### How to apply Distance sampling models using the package "Distance" implemented in R #####
##### Examples from Bylot Island: winter nest data from 2016                              #####
##### Transects sampled in three habitats: wet tudnra, mesic tundra and stream gullies    #####
##### In this file, you can find codes listed in the main text                            #####
###############################################################################################

### Load the packages
library(Distance)

### Load the winter nest file
nids2016 <- read.delim("C:/ULaval/Post-doc/Manuel_Estimations/LemmusBylot_NestTransects2016.txt")

# Winter nest densities for the mesic habitat
# Data were collected for 2 species
# This habitat was sampled in 5 different regions separated by ~10 km
# Winter nests of both species are assumed to be equally detectable
# Cosinus adjustment used as it typically offers better fit for winter nest models
mod.2016.hn.mesic <- ds(data=nids2016[nids2016$habitat=="mesic",],convert.units=0.0001,adjustment = "cos", key="hn")
mod.2016.hr.mesic <- ds(data=nids2016[nids2016$habitat=="mesic",],convert.units=0.0001,adjustment = "cos", key="hr")
mod.2016.un.mesic <- ds(data=nids2016[nids2016$habitat=="mesic",],convert.units=0.0001,adjustment = "cos", key="un")

### STOP: Assess model fit with chi-square (mainly) Kolmogorov-smirnov, and Cramer-von Mises tests ###
ds.gof(mod.2016.hn.mesic) #Adjustment of chi-square test not OK - P<0.05
ds.gof(mod.2016.hr.mesic) #Adjustment of chi-square test OK - P>0.05
ds.gof(mod.2016.un.mesic) #Adjustment of chi-square test not OK - P<0.05

### If adjustment is OK for more than one model, proceed with model selection.
# In this case for the mesic habitat, only one model was well fit with the data. Thus, we don't have to go through model selection
#AICc(mod.2016.hn.mesic) # Not applicable
#AICc(mod.2016.hr.mesic) # Not applicable
#AICc(mod.2016.un.mesic) # Not applicable

### Check summary output of the selected model and note densities.
summary(mod.2016.hr.mesic)

# Winter nest densities for the wet habitat
# This habitat was sampled in a single region
mod.2016.hn.wet <- ds(data=nids2016[nids2016$habitat=="wetland",],convert.units=0.0001,adjustment = "cos", key="hn")
mod.2016.hr.wet <- ds(data=nids2016[nids2016$habitat=="wetland",],convert.units=0.0001,adjustment = "cos", key="hr")
mod.2016.un.wet <- ds(data=nids2016[nids2016$habitat=="wetland",],convert.units=0.0001,adjustment = "cos", key="un")

### STOP: Assess model fit with chi-square (mainly) Kolmogorov-smirnov, and Cramer-von Mises tests ###
ds.gof(mod.2016.hn.wet) #Adjustment of chi-square test not OK - could not be tested, sample size is too low (n=1)
ds.gof(mod.2016.hr.wet) #Adjustment of chi-square test not OK - could not be tested, sample size is too low (n=1)
ds.gof(mod.2016.un.wet) #Adjustment of chi-square test not OK - could not be tested, sample size is too low (n=1)

# Density calculations could not be estimated for this habitat because sample size is too low.
# Thus, the minimum number of nest found is used to estimate densities.
# If we assume that we have ~100% chance of seeing a nest within 5 m, we can calculate a total area of effort. 
# Total area surveyed (gross estimation) = 20 transects x 500 m (length) x 10 m (width) / 10000 m = 10 ha
# Final winter nest density = 1/10 ha = 0.1 nest/ha
### WARNING: Note that it is best to use past covered areas that were successfully estimated by distance sampling during past years.

# Winter nest densities for the stream gullies habitat
# This habitat was sampled in the same 5 regions as for the mesic habitat
mod.2016.hn.stream <- ds(data=nids2016[nids2016$habitat=="stream",],convert.units=0.0001,adjustment = "cos", key="hn")
mod.2016.hr.stream <- ds(data=nids2016[nids2016$habitat=="stream",],convert.units=0.0001,adjustment = "cos", key="hr")
mod.2016.un.stream <- ds(data=nids2016[nids2016$habitat=="stream",],convert.units=0.0001,adjustment = "cos", key="un")

### STOP: Assess model fit with chi-square (mainly) Kolmogorov-smirnov, and Cramer-von Mises tests ###
ds.gof(mod.2016.hn.stream) #Adjustment of chi-square test OK - P>0.05
ds.gof(mod.2016.hr.stream) #Adjustment of chi-square test OK - P>0.05
ds.gof(mod.2016.un.stream) #Adjustment of chi-square test OK - P>0.05

### If adjustment is OK for more than one model, proceed with model selection.
# In this case for the stream gullies habitat, all models were well fit with the data.
AICc(mod.2016.hn.stream) # 899.63 --> this model is selected because it has the lowest AICc value.
AICc(mod.2016.hr.stream) # 900.50
AICc(mod.2016.un.stream) # 900.67

### Check summary output of the selected model and note densities.
summary(mod.2016.hn.stream)
